@@ -45,7 +45,19 @@ class FileList:
         self._update()
 
     def remove(self, idx):
-        """ Removes the given image from this FileList. """
+        """ Remove the given image from this FileList, do not delete the file. """
+        with self.mutex:
+            try:
+                filespec = self.filespecs.pop(idx)
+                self.orientations.pop(idx)
+                self.textures.pop(idx)
+                self.images.pop(idx)
+                self._update()
+            except IndexError:
+                pass
+
+    def delete(self, idx):
+        """ Remove the given image from this FileList and delete the file from disk. """
         with self.mutex:
             try:
                 filespec = self.filespecs.pop(idx)
@@ -100,6 +112,8 @@ def main():
         print("    g                       toggle sRGB gamma correction on/off")
         print("    b                       increase brightness in 0.5 EV steps")
         print("    i                       print image information (EXIF)")
+        print("    d                       drop the currently shown image")
+        print("    del                     delete the currently shown image")
         print("    q / esc / ctrl+c        terminate")
         print()
         print("  supported file types:")
